@@ -1,7 +1,7 @@
 package Log::ger::App;
 
-our $DATE = '2020-04-19'; # DATE
-our $VERSION = '0.014'; # VERSION
+our $DATE = '2020-11-02'; # DATE
+our $VERSION = '0.015'; # VERSION
 
 # IFUNBUILT
 # use strict;
@@ -141,8 +141,9 @@ sub import {
         my $file_dir  = delete $args{file_dir};
         unless (defined $file_dir) {
             require PERLANCAR::File::HomeDir;
-            $file_dir = $> ? PERLANCAR::File::HomeDir::get_my_home_dir() :
-                (-d "/var/log" ? "/var/log" : "/");
+            $file_dir = $> || $^O eq 'MSWin32' ?
+                PERLANCAR::File::HomeDir::get_my_home_dir() :
+                  (-d "/var/log" ? "/var/log" : "/");
         }
 
         last if $0 eq '-';
@@ -207,7 +208,7 @@ Log::ger::App - An easy way to use Log::ger in applications
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 SYNOPSIS
 
@@ -373,7 +374,7 @@ log. Normally, timestamps will only be added to the file log.
 =head2 LOG_ADD_MEMORY_INFO
 
 Boolean. Default to false. If set to true, will add memory info to log (see
-C<_{vmtime}> in L<Log::ger::Layout::Pattern>).
+C<%_{vmtime}> pattern in L<Log::ger::Layout::Pattern>).
 
 =head2 LOG_LEVEL
 
